@@ -28,13 +28,6 @@
 #include <QVariant>
 
 
-namespace Calamares
-{
-class Module;
-}
-
-void operator>>( const QVariantMap& moduleDescriptor, Calamares::Module* m );
-
 namespace Calamares
 {
 
@@ -193,8 +186,6 @@ private:
     QString m_name;
     QString m_directory;
     QString m_instanceId;
-
-    friend void ::operator>>( const QVariantMap& moduleDescriptor, Calamares::Module* m );
 };
 
 }  // namespace Calamares
