@@ -19,10 +19,11 @@
 #ifndef CALAMARES_PYTHONQTVIEWMODULE_H
 #define CALAMARES_PYTHONQTVIEWMODULE_H
 
-#include "UiDllMacro.h"
 #include "Module.h"
+#include "UiDllMacro.h"
 
-namespace Calamares {
+namespace Calamares
+{
 
 class ViewStep;
 
@@ -39,7 +40,7 @@ protected:
     void initFrom( const QVariantMap& moduleDescriptor ) override;
 
 private:
-    friend class Module; //so only the superclass can instantiate
+    friend class Module;  //so only the superclass can instantiate
     explicit PythonQtViewModule();
     virtual ~PythonQtViewModule();
 
@@ -49,6 +50,6 @@ private:
     QString m_workingPath;
 };
 
-} // namespace Calamares
+}  // namespace Calamares
 
-#endif // CALAMARES_PYTHONQTVIEWMODULE_H
+#endif  // CALAMARES_PYTHONQTVIEWMODULE_H
