@@ -72,11 +72,12 @@ private:
     bool m_mounted;
 };
 
+/// @brief Generate random data of given @p size as a QByteArray
 static QByteArray
 generateTestData( qint64 size )
 {
     QByteArray ba;
-    ba.resize( size );
+    ba.resize( static_cast<int>( size ) );
     // Fill the array explicitly to keep Valgrind happy
     for ( auto it = ba.data() ; it < ba.data() + size ; ++it )
     {
@@ -129,6 +130,11 @@ QueueRunner::QueueRunner( JobQueue* queue )
     connect( m_queue, &JobQueue::failed, this, &QueueRunner::onFailed );
 }
 
+QueueRunner::~QueueRunner()
+{
+    // Nothing to do. We don't own the queue, and disconnect happens automatically
+}
+
 bool
 QueueRunner::run()
 {
@@ -166,7 +172,8 @@ PartitionJobTests::initTestCase()
     QString devicePath = qgetenv( "CALAMARES_TEST_DISK" );
     if ( devicePath.isEmpty() )
     {
-        QSKIP( "Skipping test, CALAMARES_TEST_DISK is not set. It should point to a disk which can be safely formatted" );
+        // The 0 is to keep the macro parameters happy
+        QSKIP( "Skipping test, CALAMARES_TEST_DISK is not set. It should point to a disk which can be safely formatted", 0 );
     }
 
     QVERIFY( KPMHelpers::initKPMcore() );
@@ -321,10 +328,10 @@ PartitionJobTests::testCreatePartitionExtended()
 void
 PartitionJobTests::testResizePartition_data()
 {
-    QTest::addColumn< int >( "oldStartMB" );
-    QTest::addColumn< int >( "oldSizeMB" );
-    QTest::addColumn< int >( "newStartMB" );
-    QTest::addColumn< int >( "newSizeMB" );
+    QTest::addColumn< unsigned int >( "oldStartMiB" );
+    QTest::addColumn< unsigned int >( "oldSizeMiB" );
+    QTest::addColumn< unsigned int >( "newStartMiB" );
+    QTest::addColumn< unsigned int >( "newSizeMiB" );
 
     QTest::newRow("grow")      << 10 << 50 << 10 << 70;
     QTest::newRow("shrink")    << 10 << 70 << 10 << 50;
@@ -335,22 +342,22 @@ PartitionJobTests::testResizePartition_data()
 void
 PartitionJobTests::testResizePartition()
 {
-    QFETCH( int, oldStartMB );
-    QFETCH( int, oldSizeMB );
-    QFETCH( int, newStartMB );
-    QFETCH( int, newSizeMB );
+    QFETCH( unsigned int, oldStartMiB );
+    QFETCH( unsigned int, oldSizeMiB );
+    QFETCH( unsigned int, newStartMiB );
+    QFETCH( unsigned int, newSizeMiB );
 
-    const qint64 sectorForMB = 1_MiB / m_device->logicalSize();
+    const qint64 sectorsPerMiB = 1_MiB / m_device->logicalSize();
 
-    qint64 oldFirst = sectorForMB * oldStartMB;
-    qint64 oldLast  = oldFirst + sectorForMB * oldSizeMB - 1;
-    qint64 newFirst = sectorForMB * newStartMB;
-    qint64 newLast  = newFirst + sectorForMB * newSizeMB - 1;
+    qint64 oldFirst = sectorsPerMiB * oldStartMiB;
+    qint64 oldLast  = oldFirst + sectorsPerMiB * oldSizeMiB - 1;
+    qint64 newFirst = sectorsPerMiB * newStartMiB;
+    qint64 newLast  = newFirst + sectorsPerMiB * newSizeMiB - 1;
 
     // Make the test data file smaller than the full size of the partition to
     // accomodate for the file system overhead
-    const unsigned long long minSizeMB = qMin( oldSizeMB, newSizeMB );
-    const QByteArray testData = generateTestData( CalamaresUtils::MiBtoBytes( minSizeMB ) * 3 / 4 );
+    const unsigned long long minSizeMiB = qMin( oldSizeMiB, newSizeMiB );
+    const QByteArray testData = generateTestData( CalamaresUtils::MiBtoBytes( minSizeMiB ) * 3 / 4 );
     const QString testName = "test.data";
 
     // Setup: create the test partition
