@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Portions from the Manjaro Installation Framework
  *   by Roland Singer <roland@manjaro.org>
@@ -24,9 +24,8 @@
 #ifndef USERSPAGE_H
 #define USERSPAGE_H
 
-#include "Typedefs.h"
-
 #include "CheckPWQuality.h"
+#include "Job.h"
 
 #include <QWidget>
 
@@ -44,7 +43,7 @@ public:
 
     bool isReady();
 
-    QList< Calamares::job_ptr > createJobs( const QStringList& defaultGroupsList );
+    Calamares::JobList createJobs( const QStringList& defaultGroupsList );
 
     void onActivate();
 
@@ -52,6 +51,12 @@ public:
     void setAutologinDefault( bool checked );
     void setReusePasswordDefault( bool checked );
 
+    /** @brief Process entries in the passwordRequirements config entry
+     *
+     * Called once for each item in the config entry, which should
+     * be a key-value pair. What makes sense as a value depends on
+     * the key. Supported keys are documented in users.conf.
+     */
     void addPasswordCheck( const QString& key, const QVariant& value );
 
 protected slots:
